@@ -26,7 +26,6 @@
 #include "tepl-file.h"
 #include "tepl-signal-group.h"
 #include "tepl-tab.h"
-#include "tepl-tab-group.h"
 #include "tepl-view.h"
 
 /**
@@ -164,7 +163,7 @@ open_cb (GSimpleAction *open_action,
 
 	/* Create a GtkFileChooserDialog, not a GtkFileChooserNative, because
 	 * with GtkFileChooserNative the GFile that we obtain (in flatpak)
-	 * doesn't have the real path to the file, so it would screw up some
+	 * doesn't have the real path to the file, so it would ruin some
 	 * features for text editors:
 	 * - showing the directory in parentheses in the window title, or in the
 	 *   tab tooltip;
