@@ -6,7 +6,7 @@
  * Copyright 2000, 2002 - Chema Celorio, Paolo Maggi
  * Copyright 2003-2005 - Paolo Maggi
  *
- * Copyright 2016, 2017 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright 2016-2020 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * Tepl is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
@@ -310,30 +310,31 @@ null_ptr (gchar **ptr)
 	}
 }
 
-/*
- * _tepl_utils_decode_uri:
+/**
+ * tepl_utils_decode_uri:
  * @uri: the uri to decode
  * @scheme: (out) (optional): return value pointer for the uri's
  *     scheme (e.g. http, sftp, ...), or %NULL
  * @user: (out) (optional): return value pointer for the uri user info, or %NULL
- * @port: (out) (optional): return value pointer for the uri port, or %NULL
  * @host: (out) (optional): return value pointer for the uri host, or %NULL
+ * @port: (out) (optional): return value pointer for the uri port, or %NULL
  * @path: (out) (optional): return value pointer for the uri path, or %NULL
  *
  * Parse and break an uri apart in its individual components like the uri
- * scheme, user info, port, host and path. The return value pointer can be
+ * scheme, user info, host, port and path. The return value pointer can be
  * %NULL to ignore certain parts of the uri. If the function returns %TRUE, then
  * all return value pointers should be freed using g_free().
  *
  * Returns: %TRUE if the uri could be properly decoded, %FALSE otherwise.
+ * Since: 5.0
  */
 gboolean
-_tepl_utils_decode_uri (const gchar  *uri,
-			gchar       **scheme,
-			gchar       **user,
-			gchar       **host,
-			gchar       **port,
-			gchar       **path)
+tepl_utils_decode_uri (const gchar  *uri,
+		       gchar       **scheme,
+		       gchar       **user,
+		       gchar       **host,
+		       gchar       **port,
+		       gchar       **path)
 {
 	/* Largely copied from glib/gio/gdummyfile.c: _g_decode_uri().
 	 * This functionality is currently not in GLib/GIO, so for now we
@@ -508,8 +509,119 @@ _tepl_utils_get_fallback_basename_for_display (GFile *location)
 	return basename;
 }
 
+/**
+ * tepl_utils_create_parent_directories:
+ * @file: a file
+ * @cancellable: (nullable): optional #GCancellable object, %NULL to ignore.
+ * @error: (out) (optional): a location to a %NULL #GError, or %NULL.
+ *
+ * Synchronously creates parent directories of @file, so that @file can be
+ * saved.
+ *
+ * Returns: whether the directories are correctly created. %FALSE is returned on
+ * error.
+ * Since: 5.0
+ */
+gboolean
+tepl_utils_create_parent_directories (GFile         *file,
+				      GCancellable  *cancellable,
+				      GError       **error)
+{
+	GFile *parent;
+	GError *my_error = NULL;
+
+	g_return_val_if_fail (G_IS_FILE (file), FALSE);
+	g_return_val_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable), FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+	parent = g_file_get_parent (file);
+
+	if (parent == NULL)
+	{
+		return TRUE;
+	}
+
+	g_file_make_directory_with_parents (parent, cancellable, &my_error);
+	g_clear_object (&parent);
+
+	if (g_error_matches (my_error, G_IO_ERROR, G_IO_ERROR_EXISTS))
+	{
+		g_error_free (my_error);
+		return TRUE;
+	}
+	if (my_error != NULL)
+	{
+		g_propagate_error (error, my_error);
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+/**
+ * tepl_utils_file_query_exists_async:
+ * @file: a #GFile.
+ * @cancellable: a #GCancellable.
+ * @callback: the callback to call when the operation is finished.
+ * @user_data: the data to pass to the callback function.
+ *
+ * The asynchronous version of g_file_query_exists(). When the operation is
+ * finished, @callback will be called. You can then call
+ * tepl_utils_file_query_exists_finish() to get the result of the operation.
+ *
+ * Since: 5.0
+ */
+void
+tepl_utils_file_query_exists_async (GFile               *file,
+				    GCancellable        *cancellable,
+				    GAsyncReadyCallback  callback,
+				    gpointer             user_data)
+{
+	g_file_query_info_async (file,
+				 G_FILE_ATTRIBUTE_STANDARD_TYPE,
+				 G_FILE_QUERY_INFO_NONE,
+				 G_PRIORITY_DEFAULT,
+				 cancellable,
+				 callback,
+				 user_data);
+}
+
+/**
+ * tepl_utils_file_query_exists_finish:
+ * @file: a #GFile.
+ * @result: a #GAsyncResult.
+ *
+ * Finishes the operation started with tepl_utils_file_query_exists_async().
+ * There is no output #GError parameter, so you should check if the operation
+ * has been cancelled (in which case %FALSE will be returned).
+ *
+ * Returns: %TRUE if the file exists and the operation hasn't been cancelled,
+ * %FALSE otherwise.
+ * Since: 5.0
+ */
+gboolean
+tepl_utils_file_query_exists_finish (GFile        *file,
+				     GAsyncResult *result)
+{
+	GFileInfo *info = g_file_query_info_finish (file, result, NULL);
+
+	if (info != NULL)
+	{
+		g_object_unref (info);
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+/**
+ * tepl_utils_create_close_button:
+ *
+ * Returns: (transfer floating): a new close button (a #GtkButton).
+ * Since: 5.0
+ */
 GtkWidget *
-_tepl_utils_create_close_button (void)
+tepl_utils_create_close_button (void)
 {
 	GtkWidget *close_button;
 	GtkStyleContext *style_context;
@@ -575,3 +687,60 @@ _tepl_utils_associate_secondary_window (GtkWindow *secondary_window,
 		gtk_window_group_add_window (window_group, secondary_window);
 	}
 }
+
+/**
+ * tepl_utils_show_warning_dialog:
+ * @parent: (nullable): the #GtkWindow issuing the warning.
+ * @format: format string, as with printf().
+ * @...: parameters to insert into the format string.
+ *
+ * Shows a #GtkDialog with the provided warning message.
+ *
+ * Since: 5.0
+ */
+void
+tepl_utils_show_warning_dialog (GtkWindow   *parent,
+				const gchar *format,
+				...)
+{
+	va_list args;
+	gchar *str;
+	GtkWidget *dialog;
+	GtkWindowGroup *window_group = NULL;
+
+	g_return_if_fail (format != NULL);
+
+	if (parent != NULL)
+	{
+		window_group = gtk_window_get_group (parent);
+	}
+
+	va_start (args, format);
+	str = g_strdup_vprintf (format, args);
+	va_end (args);
+
+	dialog = gtk_message_dialog_new_with_markup (parent,
+						     GTK_DIALOG_MODAL |
+						     GTK_DIALOG_DESTROY_WITH_PARENT,
+						     GTK_MESSAGE_ERROR,
+						     GTK_BUTTONS_OK,
+						     "%s", str);
+
+	g_free (str);
+
+	if (window_group != NULL)
+	{
+		gtk_window_group_add_window (window_group, GTK_WINDOW (dialog));
+	}
+
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+
+	g_signal_connect (dialog,
+			  "response",
+			  G_CALLBACK (gtk_widget_destroy),
+			  NULL);
+
+	gtk_widget_show (dialog);
+}
