@@ -1,7 +1,7 @@
 /*
  * This file is part of Tepl, a text editor library.
  *
- * Copyright 2016, 2017 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright 2016-2020 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * Tepl is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
@@ -30,16 +30,25 @@ G_BEGIN_DECLS
 
 /* String utilities */
 
-gchar *		_tepl_utils_str_middle_truncate			(const gchar *str,
+gchar *		tepl_utils_str_middle_truncate			(const gchar *str,
 								 guint        truncate_length);
 
+gchar *		tepl_utils_str_end_truncate			(const gchar *str,
+								 guint        truncate_length);
+
+gchar *		tepl_utils_str_replace				(const gchar *string,
+								 const gchar *search,
+								 const gchar *replacement);
+
 /* File utilities */
 
-G_GNUC_INTERNAL
-gchar *		_tepl_utils_replace_home_dir_with_tilde		(const gchar *filename);
+gchar *		tepl_utils_get_file_extension			(const gchar *filename);
 
-G_GNUC_INTERNAL
-gboolean	_tepl_utils_decode_uri				(const gchar  *uri,
+gchar *		tepl_utils_get_file_shortname			(const gchar *filename);
+
+gchar *		tepl_utils_replace_home_dir_with_tilde		(const gchar *filename);
+
+gboolean	tepl_utils_decode_uri				(const gchar  *uri,
 								 gchar       **scheme,
 								 gchar       **user,
 								 gchar       **host,
@@ -49,9 +58,29 @@ gboolean	_tepl_utils_decode_uri				(const gchar  *uri,
 G_GNUC_INTERNAL
 gchar *		_tepl_utils_get_fallback_basename_for_display	(GFile *location);
 
+gboolean	tepl_utils_create_parent_directories		(GFile         *file,
+								 GCancellable  *cancellable,
+								 GError       **error);
+
+void		tepl_utils_file_query_exists_async		(GFile               *file,
+								 GCancellable        *cancellable,
+								 GAsyncReadyCallback  callback,
+								 gpointer             user_data);
+
+gboolean	tepl_utils_file_query_exists_finish		(GFile        *file,
+								 GAsyncResult *result);
+
 /* Widget utilities */
 
-GtkWidget *	_tepl_utils_create_close_button			(void);
+GtkWidget *	tepl_utils_create_close_button			(void);
+
+G_GNUC_INTERNAL
+void		_tepl_utils_associate_secondary_window		(GtkWindow *secondary_window,
+								 GtkWidget *main_window_widget);
+
+void		tepl_utils_show_warning_dialog			(GtkWindow   *parent,
+								 const gchar *format,
+								 ...) G_GNUC_PRINTF(2, 3);
 
 G_END_DECLS
 
