@@ -1,7 +1,7 @@
 /*
  * This file is part of Tepl, a text editor library.
  *
- * Copyright 2016, 2017 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright 2016-2020 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * Tepl is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
@@ -24,25 +24,32 @@
 
 #include <amtk/amtk.h>
 
-#include <tepl/tepl-types.h>
 #include <tepl/tepl-enum-types.h>
 
+#include <tepl/tepl-abstract-factory.h>
 #include <tepl/tepl-application.h>
 #include <tepl/tepl-application-window.h>
 #include <tepl/tepl-buffer.h>
 #include <tepl/tepl-encoding.h>
 #include <tepl/tepl-file.h>
 #include <tepl/tepl-file-loader.h>
-#include <tepl/tepl-file-metadata.h>
 #include <tepl/tepl-file-saver.h>
 #include <tepl/tepl-fold-region.h>
 #include <tepl/tepl-gutter-renderer-folds.h>
 #include <tepl/tepl-info-bar.h>
+#include <tepl/tepl-init.h>
+#include <tepl/tepl-io-error-info-bars.h>
 #include <tepl/tepl-iter.h>
+#include <tepl/tepl-menu-shell.h>
+#include <tepl/tepl-metadata.h>
 #include <tepl/tepl-metadata-manager.h>
 #include <tepl/tepl-notebook.h>
+#include <tepl/tepl-panel.h>
+#include <tepl/tepl-statusbar.h>
+#include <tepl/tepl-style-scheme-chooser-widget.h>
 #include <tepl/tepl-tab.h>
 #include <tepl/tepl-tab-group.h>
+#include <tepl/tepl-tab-label.h>
 #include <tepl/tepl-utils.h>
 #include <tepl/tepl-view.h>
 
